# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/models/models.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.builds import builds_pb2 as qwak_dot_builds_dot_builds__pb2
from _qwak_proto.qwak.audience.v1 import audience_pb2 as qwak_dot_audience_dot_v1_dot_audience__pb2
from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2
from _qwak_proto.qwak.build.v1 import build_pb2 as qwak_dot_build_dot_v1_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qwak/models/models.proto\x12\x16qwak.models.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18qwak/builds/builds.proto\x1a\x1fqwak/audience/v1/audience.proto\x1a qwak/deployment/deployment.proto\x1a\x19qwak/build/v1/build.proto\"K\n\x12\x43reateModelRequest\x12\x35\n\nmodel_spec\x18\x01 \x01(\x0b\x32!.qwak.models.management.ModelSpec\"\'\n\x13\x43reateModelResponse\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\'\n\x11ListModelsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"C\n\x12ListModelsResponse\x12-\n\x06models\x18\x01 \x03(\x0b\x32\x1d.qwak.models.management.Model\"I\n\x0fGetModelRequest\x12\x12\n\x08model_id\x18\x01 \x01(\tH\x00\x12\x14\n\nmodel_uuid\x18\x02 \x01(\tH\x00\x42\x0c\n\nidentifier\"@\n\x10GetModelResponse\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x1d.qwak.models.management.Model\":\n\x12\x44\x65leteModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteModelResponse\"q\n\x12UpdateModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12I\n\x11model_spec_config\x18\x02 \x01(\x0b\x32..qwak.models.management.ModelSpecConfiguration\"L\n\x13UpdateModelResponse\x12\x35\n\nmodel_spec\x18\x01 \x01(\x0b\x32!.qwak.models.management.ModelSpec\"<\n\x13\x43reateBranchRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\")\n\x14\x43reateBranchResponse\x12\x11\n\tbranch_id\x18\x01 \x01(\t\"(\n\x13\x44\x65leteBranchRequest\x12\x11\n\tbranch_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteBranchResponse\"N\n\x14IsModelExistsRequest\x12\x12\n\x08model_id\x18\x01 \x01(\tH\x00\x12\x14\n\nmodel_uuid\x18\x02 \x01(\tH\x00\x42\x0c\n\nidentifier\"\'\n\x15IsModelExistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\"\xda\x01\n\tModelSpec\x12\x16\n\x0emodel_named_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x14\n\nproject_id\x18\x03 \x01(\tH\x00\x12\x16\n\x0cproject_name\x18\x06 \x01(\tH\x00\x12\x19\n\x11model_description\x18\x04 \x01(\t\x12@\n\x10model_build_type\x18\x05 \x01(\x0b\x32&.qwak.models.management.ModelBuildTypeB\x14\n\x12project_identifier\"\xc7\x02\n\nModelBrief\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x19\n\x11model_description\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12N\n\x17\x64\x65ployment_model_status\x18\n \x01(\x0e\x32-.qwak.models.management.DeploymentModelStatus\"3\n\x16ModelSpecConfiguration\x12\x19\n\x11model_description\x18\x04 \x01(\t\"\xd9\x04\n\x05Model\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x39\n\x0cmodel_status\x18\x07 \x01(\x0e\x32#.qwak.models.management.ModelStatus\x12\x19\n\x11model_description\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x30\n\x08\x62ranches\x18\n \x03(\x0b\x32\x1e.qwak.models.management.Branch\x12N\n\x17\x64\x65ployment_model_status\x18\x0b \x01(\x0e\x32-.qwak.models.management.DeploymentModelStatus\x12\x0c\n\x04uuid\x18\x0c \x01(\t\x12\x42\n\nmodel_type\x18\r \x01(\x0e\x32..qwak.deployment.management.KubeDeploymentType\x12\x14\n\x0cproject_name\x18\x0e \x01(\t\x12@\n\x10model_build_type\x18\x0f \x01(\x0b\x32&.qwak.models.management.ModelBuildType\"\x96\x01\n\x0eModelBuildType\x12\x30\n\x06source\x18\x01 \x01(\x0b\x32\x1e.qwak.models.management.SourceH\x00\x12J\n\x14model_registry_image\x18\x02 \x01(\x0b\x32*.qwak.models.management.ModelRegistryImageH\x00\x42\x06\n\x04type\"\x08\n\x06Source\"3\n\x12ModelRegistryImage\x12\x1d\n\x15last_image_identifier\x18\x01 \x01(\t\"\xeb\x01\n\x06\x42ranch\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\x12\x42\n\rbranch_status\x18\x04 \x01(\x0e\x32+.qwak.models.management.Branch.BranchStatus\x12\x10\n\x08model_id\x18\x05 \x01(\t\x12\x1d\n\x11\x64\x65ployed_build_id\x18\x06 \x01(\tB\x02\x18\x01\"D\n\x0c\x42ranchStatus\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\r\n\tSUSPENDED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x01\"B\n\x1bGetDeploymentDetailsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x11\n\tbranch_id\x18\x02 \x01(\t\"e\n\x1cGetDeploymentDetailsResponse\x12\x45\n\x12\x64\x65ployment_details\x18\x01 \x01(\x0b\x32).qwak.models.management.DeploymentDetails\"\x93\x02\n\x11\x44\x65ploymentDetails\x12\x31\n\rlast_deployed\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x16\n\x0enumber_of_pods\x18\x03 \x01(\x05\x12\x14\n\x0c\x63pu_fraction\x18\x04 \x01(\x02\x12\x15\n\rmemory_amount\x18\x05 \x01(\x05\x12\x38\n\x0cmemory_units\x18\x06 \x01(\x0e\x32\".qwak.models.management.MemoryUnit\x12\x19\n\x11number_of_workers\x18\x07 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x08 \x01(\x05\"/\n\x19ListModelsMetadataRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"[\n\x1aListModelsMetadataResponse\x12=\n\x0emodel_metadata\x18\x01 \x03(\x0b\x32%.qwak.models.management.ModelMetadata\"+\n\x17GetModelMetadataRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"Y\n\x18GetModelMetadataResponse\x12=\n\x0emodel_metadata\x18\x01 \x01(\x0b\x32%.qwak.models.management.ModelMetadata\"h\n\x11\x45nvironmentRoutes\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12>\n\x0f\x61udience_routes\x18\x02 \x03(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry\"\xb8\x05\n\rModelMetadata\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x1d.qwak.models.management.Model\x12I\n\x12\x64\x65ployment_details\x18\x02 \x03(\x0b\x32-.qwak.deployment.management.DeploymentDetails\x12r\n\x1e\x61udience_routes_by_environment\x18\x03 \x03(\x0b\x32\x46.qwak.models.management.ModelMetadata.AudienceRoutesByEnvironmentEntryB\x02\x18\x01\x12\x30\n\x05\x62uild\x18\x04 \x03(\x0b\x32\x1d.qwak.builds.management.BuildB\x02\x18\x01\x12}\n&audience_routes_grouped_by_environment\x18\x05 \x03(\x0b\x32M.qwak.models.management.ModelMetadata.AudienceRoutesGroupedByEnvironmentEntry\x12(\n\x06\x62uilds\x18\x06 \x03(\x0b\x32\x18.com.qwak.build.v1.Build\x1ai\n AudienceRoutesByEnvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry:\x02\x38\x01\x1at\n\'AudienceRoutesGroupedByEnvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qwak.models.management.EnvironmentRoutes:\x02\x38\x01*O\n\x15\x44\x65ploymentModelStatus\x12\x1d\n\x19\x44\x45PLOYMENT_STATUS_INVALID\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07OFFLINE\x10\x02*C\n\x0bModelStatus\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\r\n\tSUSPENDED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x01*7\n\nMemoryUnit\x12\x17\n\x13MEMORY_UNIT_UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02\x32\xe0\t\n\x17ModelsManagementService\x12\x66\n\x0b\x43reateModel\x12*.qwak.models.management.CreateModelRequest\x1a+.qwak.models.management.CreateModelResponse\x12\x63\n\nListModels\x12).qwak.models.management.ListModelsRequest\x1a*.qwak.models.management.ListModelsResponse\x12]\n\x08GetModel\x12\'.qwak.models.management.GetModelRequest\x1a(.qwak.models.management.GetModelResponse\x12\x66\n\x0b\x44\x65leteModel\x12*.qwak.models.management.DeleteModelRequest\x1a+.qwak.models.management.DeleteModelResponse\x12\x66\n\x0bUpdateModel\x12*.qwak.models.management.UpdateModelRequest\x1a+.qwak.models.management.UpdateModelResponse\x12n\n\x0c\x43reateBranch\x12+.qwak.models.management.CreateBranchRequest\x1a,.qwak.models.management.CreateBranchResponse\"\x03\x88\x02\x01\x12n\n\x0c\x44\x65leteBranch\x12+.qwak.models.management.DeleteBranchRequest\x1a,.qwak.models.management.DeleteBranchResponse\"\x03\x88\x02\x01\x12\x86\x01\n\x14GetDeploymentDetails\x12\x33.qwak.models.management.GetDeploymentDetailsRequest\x1a\x34.qwak.models.management.GetDeploymentDetailsResponse\"\x03\x88\x02\x01\x12l\n\rIsModelExists\x12,.qwak.models.management.IsModelExistsRequest\x1a-.qwak.models.management.IsModelExistsResponse\x12{\n\x12ListModelsMetadata\x12\x31.qwak.models.management.ListModelsMetadataRequest\x1a\x32.qwak.models.management.ListModelsMetadataResponse\x12u\n\x10GetModelMetadata\x12/.qwak.models.management.GetModelMetadataRequest\x1a\x30.qwak.models.management.GetModelMetadataResponseB%\n!com.qwak.ai.management.models.apiP\x01\x62\x06proto3')

_DEPLOYMENTMODELSTATUS = DESCRIPTOR.enum_types_by_name['DeploymentModelStatus']
DeploymentModelStatus = enum_type_wrapper.EnumTypeWrapper(_DEPLOYMENTMODELSTATUS)
_MODELSTATUS = DESCRIPTOR.enum_types_by_name['ModelStatus']
ModelStatus = enum_type_wrapper.EnumTypeWrapper(_MODELSTATUS)
_MEMORYUNIT = DESCRIPTOR.enum_types_by_name['MemoryUnit']
MemoryUnit = enum_type_wrapper.EnumTypeWrapper(_MEMORYUNIT)
DEPLOYMENT_STATUS_INVALID = 0
ONLINE = 1
OFFLINE = 2
INVALID = 0
ACTIVE = 3
SUSPENDED = 2
DISABLED = 1
MEMORY_UNIT_UNKNOWN = 0
MIB = 1
GIB = 2


_CREATEMODELREQUEST = DESCRIPTOR.message_types_by_name['CreateModelRequest']
_CREATEMODELRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelResponse']
_LISTMODELSREQUEST = DESCRIPTOR.message_types_by_name['ListModelsRequest']
_LISTMODELSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelsResponse']
_GETMODELREQUEST = DESCRIPTOR.message_types_by_name['GetModelRequest']
_GETMODELRESPONSE = DESCRIPTOR.message_types_by_name['GetModelResponse']
_DELETEMODELREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelRequest']
_DELETEMODELRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelResponse']
_UPDATEMODELREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelRequest']
_UPDATEMODELRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelResponse']
_CREATEBRANCHREQUEST = DESCRIPTOR.message_types_by_name['CreateBranchRequest']
_CREATEBRANCHRESPONSE = DESCRIPTOR.message_types_by_name['CreateBranchResponse']
_DELETEBRANCHREQUEST = DESCRIPTOR.message_types_by_name['DeleteBranchRequest']
_DELETEBRANCHRESPONSE = DESCRIPTOR.message_types_by_name['DeleteBranchResponse']
_ISMODELEXISTSREQUEST = DESCRIPTOR.message_types_by_name['IsModelExistsRequest']
_ISMODELEXISTSRESPONSE = DESCRIPTOR.message_types_by_name['IsModelExistsResponse']
_MODELSPEC = DESCRIPTOR.message_types_by_name['ModelSpec']
_MODELBRIEF = DESCRIPTOR.message_types_by_name['ModelBrief']
_MODELSPECCONFIGURATION = DESCRIPTOR.message_types_by_name['ModelSpecConfiguration']
_MODEL = DESCRIPTOR.message_types_by_name['Model']
_MODELBUILDTYPE = DESCRIPTOR.message_types_by_name['ModelBuildType']
_SOURCE = DESCRIPTOR.message_types_by_name['Source']
_MODELREGISTRYIMAGE = DESCRIPTOR.message_types_by_name['ModelRegistryImage']
_BRANCH = DESCRIPTOR.message_types_by_name['Branch']
_GETDEPLOYMENTDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetDeploymentDetailsRequest']
_GETDEPLOYMENTDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetDeploymentDetailsResponse']
_DEPLOYMENTDETAILS = DESCRIPTOR.message_types_by_name['DeploymentDetails']
_LISTMODELSMETADATAREQUEST = DESCRIPTOR.message_types_by_name['ListModelsMetadataRequest']
_LISTMODELSMETADATARESPONSE = DESCRIPTOR.message_types_by_name['ListModelsMetadataResponse']
_GETMODELMETADATAREQUEST = DESCRIPTOR.message_types_by_name['GetModelMetadataRequest']
_GETMODELMETADATARESPONSE = DESCRIPTOR.message_types_by_name['GetModelMetadataResponse']
_ENVIRONMENTROUTES = DESCRIPTOR.message_types_by_name['EnvironmentRoutes']
_MODELMETADATA = DESCRIPTOR.message_types_by_name['ModelMetadata']
_MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY = _MODELMETADATA.nested_types_by_name['AudienceRoutesByEnvironmentEntry']
_MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY = _MODELMETADATA.nested_types_by_name['AudienceRoutesGroupedByEnvironmentEntry']
_BRANCH_BRANCHSTATUS = _BRANCH.enum_types_by_name['BranchStatus']
CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

CreateModelResponse = _reflection.GeneratedProtocolMessageType('CreateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.CreateModelResponse)
  })
_sym_db.RegisterMessage(CreateModelResponse)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

GetModelResponse = _reflection.GeneratedProtocolMessageType('GetModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.GetModelResponse)
  })
_sym_db.RegisterMessage(GetModelResponse)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

DeleteModelResponse = _reflection.GeneratedProtocolMessageType('DeleteModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.DeleteModelResponse)
  })
_sym_db.RegisterMessage(DeleteModelResponse)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

UpdateModelResponse = _reflection.GeneratedProtocolMessageType('UpdateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.UpdateModelResponse)
  })
_sym_db.RegisterMessage(UpdateModelResponse)

CreateBranchRequest = _reflection.GeneratedProtocolMessageType('CreateBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBRANCHREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.CreateBranchRequest)
  })
_sym_db.RegisterMessage(CreateBranchRequest)

CreateBranchResponse = _reflection.GeneratedProtocolMessageType('CreateBranchResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBRANCHRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.CreateBranchResponse)
  })
_sym_db.RegisterMessage(CreateBranchResponse)

DeleteBranchRequest = _reflection.GeneratedProtocolMessageType('DeleteBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBRANCHREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.DeleteBranchRequest)
  })
_sym_db.RegisterMessage(DeleteBranchRequest)

DeleteBranchResponse = _reflection.GeneratedProtocolMessageType('DeleteBranchResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBRANCHRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.DeleteBranchResponse)
  })
_sym_db.RegisterMessage(DeleteBranchResponse)

IsModelExistsRequest = _reflection.GeneratedProtocolMessageType('IsModelExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISMODELEXISTSREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.IsModelExistsRequest)
  })
_sym_db.RegisterMessage(IsModelExistsRequest)

IsModelExistsResponse = _reflection.GeneratedProtocolMessageType('IsModelExistsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISMODELEXISTSRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.IsModelExistsResponse)
  })
_sym_db.RegisterMessage(IsModelExistsResponse)

ModelSpec = _reflection.GeneratedProtocolMessageType('ModelSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELSPEC,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ModelSpec)
  })
_sym_db.RegisterMessage(ModelSpec)

ModelBrief = _reflection.GeneratedProtocolMessageType('ModelBrief', (_message.Message,), {
  'DESCRIPTOR' : _MODELBRIEF,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ModelBrief)
  })
_sym_db.RegisterMessage(ModelBrief)

ModelSpecConfiguration = _reflection.GeneratedProtocolMessageType('ModelSpecConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _MODELSPECCONFIGURATION,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ModelSpecConfiguration)
  })
_sym_db.RegisterMessage(ModelSpecConfiguration)

Model = _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), {
  'DESCRIPTOR' : _MODEL,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.Model)
  })
_sym_db.RegisterMessage(Model)

ModelBuildType = _reflection.GeneratedProtocolMessageType('ModelBuildType', (_message.Message,), {
  'DESCRIPTOR' : _MODELBUILDTYPE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ModelBuildType)
  })
_sym_db.RegisterMessage(ModelBuildType)

Source = _reflection.GeneratedProtocolMessageType('Source', (_message.Message,), {
  'DESCRIPTOR' : _SOURCE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.Source)
  })
_sym_db.RegisterMessage(Source)

ModelRegistryImage = _reflection.GeneratedProtocolMessageType('ModelRegistryImage', (_message.Message,), {
  'DESCRIPTOR' : _MODELREGISTRYIMAGE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ModelRegistryImage)
  })
_sym_db.RegisterMessage(ModelRegistryImage)

Branch = _reflection.GeneratedProtocolMessageType('Branch', (_message.Message,), {
  'DESCRIPTOR' : _BRANCH,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.Branch)
  })
_sym_db.RegisterMessage(Branch)

GetDeploymentDetailsRequest = _reflection.GeneratedProtocolMessageType('GetDeploymentDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYMENTDETAILSREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.GetDeploymentDetailsRequest)
  })
_sym_db.RegisterMessage(GetDeploymentDetailsRequest)

GetDeploymentDetailsResponse = _reflection.GeneratedProtocolMessageType('GetDeploymentDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYMENTDETAILSRESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.GetDeploymentDetailsResponse)
  })
_sym_db.RegisterMessage(GetDeploymentDetailsResponse)

DeploymentDetails = _reflection.GeneratedProtocolMessageType('DeploymentDetails', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTDETAILS,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.DeploymentDetails)
  })
_sym_db.RegisterMessage(DeploymentDetails)

ListModelsMetadataRequest = _reflection.GeneratedProtocolMessageType('ListModelsMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSMETADATAREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ListModelsMetadataRequest)
  })
_sym_db.RegisterMessage(ListModelsMetadataRequest)

ListModelsMetadataResponse = _reflection.GeneratedProtocolMessageType('ListModelsMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSMETADATARESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ListModelsMetadataResponse)
  })
_sym_db.RegisterMessage(ListModelsMetadataResponse)

GetModelMetadataRequest = _reflection.GeneratedProtocolMessageType('GetModelMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELMETADATAREQUEST,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.GetModelMetadataRequest)
  })
_sym_db.RegisterMessage(GetModelMetadataRequest)

GetModelMetadataResponse = _reflection.GeneratedProtocolMessageType('GetModelMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELMETADATARESPONSE,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.GetModelMetadataResponse)
  })
_sym_db.RegisterMessage(GetModelMetadataResponse)

EnvironmentRoutes = _reflection.GeneratedProtocolMessageType('EnvironmentRoutes', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTROUTES,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.EnvironmentRoutes)
  })
_sym_db.RegisterMessage(EnvironmentRoutes)

ModelMetadata = _reflection.GeneratedProtocolMessageType('ModelMetadata', (_message.Message,), {

  'AudienceRoutesByEnvironmentEntry' : _reflection.GeneratedProtocolMessageType('AudienceRoutesByEnvironmentEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY,
    '__module__' : 'qwak.models.models_pb2'
    # @@protoc_insertion_point(class_scope:qwak.models.management.ModelMetadata.AudienceRoutesByEnvironmentEntry)
    })
  ,

  'AudienceRoutesGroupedByEnvironmentEntry' : _reflection.GeneratedProtocolMessageType('AudienceRoutesGroupedByEnvironmentEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY,
    '__module__' : 'qwak.models.models_pb2'
    # @@protoc_insertion_point(class_scope:qwak.models.management.ModelMetadata.AudienceRoutesGroupedByEnvironmentEntry)
    })
  ,
  'DESCRIPTOR' : _MODELMETADATA,
  '__module__' : 'qwak.models.models_pb2'
  # @@protoc_insertion_point(class_scope:qwak.models.management.ModelMetadata)
  })
_sym_db.RegisterMessage(ModelMetadata)
_sym_db.RegisterMessage(ModelMetadata.AudienceRoutesByEnvironmentEntry)
_sym_db.RegisterMessage(ModelMetadata.AudienceRoutesGroupedByEnvironmentEntry)

_MODELSMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['ModelsManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.management.models.apiP\001'
  _BRANCH.fields_by_name['deployed_build_id']._options = None
  _BRANCH.fields_by_name['deployed_build_id']._serialized_options = b'\030\001'
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._options = None
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._serialized_options = b'8\001'
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._options = None
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._serialized_options = b'8\001'
  _MODELMETADATA.fields_by_name['audience_routes_by_environment']._options = None
  _MODELMETADATA.fields_by_name['audience_routes_by_environment']._serialized_options = b'\030\001'
  _MODELMETADATA.fields_by_name['build']._options = None
  _MODELMETADATA.fields_by_name['build']._serialized_options = b'\030\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['CreateBranch']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['CreateBranch']._serialized_options = b'\210\002\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['DeleteBranch']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['DeleteBranch']._serialized_options = b'\210\002\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['GetDeploymentDetails']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['GetDeploymentDetails']._serialized_options = b'\210\002\001'
  _DEPLOYMENTMODELSTATUS._serialized_start=4336
  _DEPLOYMENTMODELSTATUS._serialized_end=4415
  _MODELSTATUS._serialized_start=4417
  _MODELSTATUS._serialized_end=4484
  _MEMORYUNIT._serialized_start=4486
  _MEMORYUNIT._serialized_end=4541
  _CREATEMODELREQUEST._serialized_start=205
  _CREATEMODELREQUEST._serialized_end=280
  _CREATEMODELRESPONSE._serialized_start=282
  _CREATEMODELRESPONSE._serialized_end=321
  _LISTMODELSREQUEST._serialized_start=323
  _LISTMODELSREQUEST._serialized_end=362
  _LISTMODELSRESPONSE._serialized_start=364
  _LISTMODELSRESPONSE._serialized_end=431
  _GETMODELREQUEST._serialized_start=433
  _GETMODELREQUEST._serialized_end=506
  _GETMODELRESPONSE._serialized_start=508
  _GETMODELRESPONSE._serialized_end=572
  _DELETEMODELREQUEST._serialized_start=574
  _DELETEMODELREQUEST._serialized_end=632
  _DELETEMODELRESPONSE._serialized_start=634
  _DELETEMODELRESPONSE._serialized_end=655
  _UPDATEMODELREQUEST._serialized_start=657
  _UPDATEMODELREQUEST._serialized_end=770
  _UPDATEMODELRESPONSE._serialized_start=772
  _UPDATEMODELRESPONSE._serialized_end=848
  _CREATEBRANCHREQUEST._serialized_start=850
  _CREATEBRANCHREQUEST._serialized_end=910
  _CREATEBRANCHRESPONSE._serialized_start=912
  _CREATEBRANCHRESPONSE._serialized_end=953
  _DELETEBRANCHREQUEST._serialized_start=955
  _DELETEBRANCHREQUEST._serialized_end=995
  _DELETEBRANCHRESPONSE._serialized_start=997
  _DELETEBRANCHRESPONSE._serialized_end=1019
  _ISMODELEXISTSREQUEST._serialized_start=1021
  _ISMODELEXISTSREQUEST._serialized_end=1099
  _ISMODELEXISTSRESPONSE._serialized_start=1101
  _ISMODELEXISTSRESPONSE._serialized_end=1140
  _MODELSPEC._serialized_start=1143
  _MODELSPEC._serialized_end=1361
  _MODELBRIEF._serialized_start=1364
  _MODELBRIEF._serialized_end=1691
  _MODELSPECCONFIGURATION._serialized_start=1693
  _MODELSPECCONFIGURATION._serialized_end=1744
  _MODEL._serialized_start=1747
  _MODEL._serialized_end=2348
  _MODELBUILDTYPE._serialized_start=2351
  _MODELBUILDTYPE._serialized_end=2501
  _SOURCE._serialized_start=2503
  _SOURCE._serialized_end=2511
  _MODELREGISTRYIMAGE._serialized_start=2513
  _MODELREGISTRYIMAGE._serialized_end=2564
  _BRANCH._serialized_start=2567
  _BRANCH._serialized_end=2802
  _BRANCH_BRANCHSTATUS._serialized_start=2734
  _BRANCH_BRANCHSTATUS._serialized_end=2802
  _GETDEPLOYMENTDETAILSREQUEST._serialized_start=2804
  _GETDEPLOYMENTDETAILSREQUEST._serialized_end=2870
  _GETDEPLOYMENTDETAILSRESPONSE._serialized_start=2872
  _GETDEPLOYMENTDETAILSRESPONSE._serialized_end=2973
  _DEPLOYMENTDETAILS._serialized_start=2976
  _DEPLOYMENTDETAILS._serialized_end=3251
  _LISTMODELSMETADATAREQUEST._serialized_start=3253
  _LISTMODELSMETADATAREQUEST._serialized_end=3300
  _LISTMODELSMETADATARESPONSE._serialized_start=3302
  _LISTMODELSMETADATARESPONSE._serialized_end=3393
  _GETMODELMETADATAREQUEST._serialized_start=3395
  _GETMODELMETADATAREQUEST._serialized_end=3438
  _GETMODELMETADATARESPONSE._serialized_start=3440
  _GETMODELMETADATARESPONSE._serialized_end=3529
  _ENVIRONMENTROUTES._serialized_start=3531
  _ENVIRONMENTROUTES._serialized_end=3635
  _MODELMETADATA._serialized_start=3638
  _MODELMETADATA._serialized_end=4334
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._serialized_start=4111
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._serialized_end=4216
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._serialized_start=4218
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._serialized_end=4334
  _MODELSMANAGEMENTSERVICE._serialized_start=4544
  _MODELSMANAGEMENTSERVICE._serialized_end=5792
# @@protoc_insertion_point(module_scope)
