# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/monitoring/v0/alerting_channel_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.monitoring.v0 import alerting_channel_pb2 as qwak_dot_monitoring_dot_v0_dot_alerting__channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<qwak/monitoring/v0/alerting_channel_management_service.proto\x12\x12qwak.monitoring.v0\x1a)qwak/monitoring/v0/alerting_channel.proto\"a\n\x1c\x43reateAlertingChannelRequest\x12\x41\n\x07options\x18\x01 \x01(\x0b\x32\x30.qwak.monitoring.v0.AlertingChannelCreateOptions\"\x1f\n\x1d\x43reateAlertingChannelResponse\"a\n\x1cUpdateAlertingChannelRequest\x12\x41\n\x07options\x18\x01 \x01(\x0b\x32\x30.qwak.monitoring.v0.AlertingChannelUpdateOptions\"\x1f\n\x1dUpdateAlertingChannelResponse\"+\n\x1dGetAlertingChannelRequestById\x12\n\n\x02id\x18\x01 \x01(\t\"e\n\x1eGetAlertingChannelResponseById\x12\x43\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\"/\n\x1fGetAlertingChannelRequestByName\x12\x0c\n\x04name\x18\x01 \x01(\t\"g\n GetAlertingChannelResponseByName\x12\x43\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\"\x1c\n\x1aListAlertingChannelRequest\"b\n\x1bListAlertingChannelResponse\x12\x43\n\x0b\x64\x65scription\x18\x01 \x03(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\",\n\x1c\x44\x65leteAlertingChannelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1f\n\x1d\x44\x65leteAlertingChannelResponse2\x9d\x06\n AlertingChannelManagementService\x12|\n\x15\x43reateAlertingChannel\x12\x30.qwak.monitoring.v0.CreateAlertingChannelRequest\x1a\x31.qwak.monitoring.v0.CreateAlertingChannelResponse\x12|\n\x15UpdateAlertingChannel\x12\x30.qwak.monitoring.v0.UpdateAlertingChannelRequest\x1a\x31.qwak.monitoring.v0.UpdateAlertingChannelResponse\x12\x7f\n\x16GetAlertingChannelById\x12\x31.qwak.monitoring.v0.GetAlertingChannelRequestById\x1a\x32.qwak.monitoring.v0.GetAlertingChannelResponseById\x12\x85\x01\n\x18GetAlertingChannelByName\x12\x33.qwak.monitoring.v0.GetAlertingChannelRequestByName\x1a\x34.qwak.monitoring.v0.GetAlertingChannelResponseByName\x12v\n\x13ListAlertingChannel\x12..qwak.monitoring.v0.ListAlertingChannelRequest\x1a/.qwak.monitoring.v0.ListAlertingChannelResponse\x12|\n\x15\x44\x65leteAlertingChannel\x12\x30.qwak.monitoring.v0.DeleteAlertingChannelRequest\x1a\x31.qwak.monitoring.v0.DeleteAlertingChannelResponseB2\n\x1d\x63om.qwak.ai.monitoring.api.v0P\x01Z\x0f.;monitoring_v0b\x06proto3')



_CREATEALERTINGCHANNELREQUEST = DESCRIPTOR.message_types_by_name['CreateAlertingChannelRequest']
_CREATEALERTINGCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['CreateAlertingChannelResponse']
_UPDATEALERTINGCHANNELREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertingChannelRequest']
_UPDATEALERTINGCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAlertingChannelResponse']
_GETALERTINGCHANNELREQUESTBYID = DESCRIPTOR.message_types_by_name['GetAlertingChannelRequestById']
_GETALERTINGCHANNELRESPONSEBYID = DESCRIPTOR.message_types_by_name['GetAlertingChannelResponseById']
_GETALERTINGCHANNELREQUESTBYNAME = DESCRIPTOR.message_types_by_name['GetAlertingChannelRequestByName']
_GETALERTINGCHANNELRESPONSEBYNAME = DESCRIPTOR.message_types_by_name['GetAlertingChannelResponseByName']
_LISTALERTINGCHANNELREQUEST = DESCRIPTOR.message_types_by_name['ListAlertingChannelRequest']
_LISTALERTINGCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertingChannelResponse']
_DELETEALERTINGCHANNELREQUEST = DESCRIPTOR.message_types_by_name['DeleteAlertingChannelRequest']
_DELETEALERTINGCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['DeleteAlertingChannelResponse']
CreateAlertingChannelRequest = _reflection.GeneratedProtocolMessageType('CreateAlertingChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTINGCHANNELREQUEST,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.CreateAlertingChannelRequest)
  })
_sym_db.RegisterMessage(CreateAlertingChannelRequest)

CreateAlertingChannelResponse = _reflection.GeneratedProtocolMessageType('CreateAlertingChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTINGCHANNELRESPONSE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.CreateAlertingChannelResponse)
  })
_sym_db.RegisterMessage(CreateAlertingChannelResponse)

UpdateAlertingChannelRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertingChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTINGCHANNELREQUEST,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.UpdateAlertingChannelRequest)
  })
_sym_db.RegisterMessage(UpdateAlertingChannelRequest)

UpdateAlertingChannelResponse = _reflection.GeneratedProtocolMessageType('UpdateAlertingChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTINGCHANNELRESPONSE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.UpdateAlertingChannelResponse)
  })
_sym_db.RegisterMessage(UpdateAlertingChannelResponse)

GetAlertingChannelRequestById = _reflection.GeneratedProtocolMessageType('GetAlertingChannelRequestById', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTINGCHANNELREQUESTBYID,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.GetAlertingChannelRequestById)
  })
_sym_db.RegisterMessage(GetAlertingChannelRequestById)

GetAlertingChannelResponseById = _reflection.GeneratedProtocolMessageType('GetAlertingChannelResponseById', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTINGCHANNELRESPONSEBYID,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.GetAlertingChannelResponseById)
  })
_sym_db.RegisterMessage(GetAlertingChannelResponseById)

GetAlertingChannelRequestByName = _reflection.GeneratedProtocolMessageType('GetAlertingChannelRequestByName', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTINGCHANNELREQUESTBYNAME,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.GetAlertingChannelRequestByName)
  })
_sym_db.RegisterMessage(GetAlertingChannelRequestByName)

GetAlertingChannelResponseByName = _reflection.GeneratedProtocolMessageType('GetAlertingChannelResponseByName', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTINGCHANNELRESPONSEBYNAME,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.GetAlertingChannelResponseByName)
  })
_sym_db.RegisterMessage(GetAlertingChannelResponseByName)

ListAlertingChannelRequest = _reflection.GeneratedProtocolMessageType('ListAlertingChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTINGCHANNELREQUEST,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.ListAlertingChannelRequest)
  })
_sym_db.RegisterMessage(ListAlertingChannelRequest)

ListAlertingChannelResponse = _reflection.GeneratedProtocolMessageType('ListAlertingChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTINGCHANNELRESPONSE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.ListAlertingChannelResponse)
  })
_sym_db.RegisterMessage(ListAlertingChannelResponse)

DeleteAlertingChannelRequest = _reflection.GeneratedProtocolMessageType('DeleteAlertingChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTINGCHANNELREQUEST,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.DeleteAlertingChannelRequest)
  })
_sym_db.RegisterMessage(DeleteAlertingChannelRequest)

DeleteAlertingChannelResponse = _reflection.GeneratedProtocolMessageType('DeleteAlertingChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTINGCHANNELRESPONSE,
  '__module__' : 'qwak.monitoring.v0.alerting_channel_management_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.monitoring.v0.DeleteAlertingChannelResponse)
  })
_sym_db.RegisterMessage(DeleteAlertingChannelResponse)

_ALERTINGCHANNELMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['AlertingChannelManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.monitoring.api.v0P\001Z\017.;monitoring_v0'
  _CREATEALERTINGCHANNELREQUEST._serialized_start=127
  _CREATEALERTINGCHANNELREQUEST._serialized_end=224
  _CREATEALERTINGCHANNELRESPONSE._serialized_start=226
  _CREATEALERTINGCHANNELRESPONSE._serialized_end=257
  _UPDATEALERTINGCHANNELREQUEST._serialized_start=259
  _UPDATEALERTINGCHANNELREQUEST._serialized_end=356
  _UPDATEALERTINGCHANNELRESPONSE._serialized_start=358
  _UPDATEALERTINGCHANNELRESPONSE._serialized_end=389
  _GETALERTINGCHANNELREQUESTBYID._serialized_start=391
  _GETALERTINGCHANNELREQUESTBYID._serialized_end=434
  _GETALERTINGCHANNELRESPONSEBYID._serialized_start=436
  _GETALERTINGCHANNELRESPONSEBYID._serialized_end=537
  _GETALERTINGCHANNELREQUESTBYNAME._serialized_start=539
  _GETALERTINGCHANNELREQUESTBYNAME._serialized_end=586
  _GETALERTINGCHANNELRESPONSEBYNAME._serialized_start=588
  _GETALERTINGCHANNELRESPONSEBYNAME._serialized_end=691
  _LISTALERTINGCHANNELREQUEST._serialized_start=693
  _LISTALERTINGCHANNELREQUEST._serialized_end=721
  _LISTALERTINGCHANNELRESPONSE._serialized_start=723
  _LISTALERTINGCHANNELRESPONSE._serialized_end=821
  _DELETEALERTINGCHANNELREQUEST._serialized_start=823
  _DELETEALERTINGCHANNELREQUEST._serialized_end=867
  _DELETEALERTINGCHANNELRESPONSE._serialized_start=869
  _DELETEALERTINGCHANNELRESPONSE._serialized_end=900
  _ALERTINGCHANNELMANAGEMENTSERVICE._serialized_start=903
  _ALERTINGCHANNELMANAGEMENTSERVICE._serialized_end=1700
# @@protoc_insertion_point(module_scope)
