"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.monitoring.v0.alerting_channel_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateAlertingChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelCreateOptions:
        """Parameters for creating an alerting channel"""
    def __init__(
        self,
        *,
        options: qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelCreateOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___CreateAlertingChannelRequest = CreateAlertingChannelRequest

class CreateAlertingChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreateAlertingChannelResponse = CreateAlertingChannelResponse

class UpdateAlertingChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelUpdateOptions:
        """Parameters for updating an alerting channel"""
    def __init__(
        self,
        *,
        options: qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelUpdateOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___UpdateAlertingChannelRequest = UpdateAlertingChannelRequest

class UpdateAlertingChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateAlertingChannelResponse = UpdateAlertingChannelResponse

class GetAlertingChannelRequestById(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Id of the required alerting channel"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GetAlertingChannelRequestById = GetAlertingChannelRequestById

class GetAlertingChannelResponseById(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelDescription:
        """Alerting channel for the given id"""
    def __init__(
        self,
        *,
        description: qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["description", b"description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___GetAlertingChannelResponseById = GetAlertingChannelResponseById

class GetAlertingChannelRequestByName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the required alerting channel"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetAlertingChannelRequestByName = GetAlertingChannelRequestByName

class GetAlertingChannelResponseByName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelDescription:
        """Alerting channel for the given id"""
    def __init__(
        self,
        *,
        description: qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["description", b"description"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___GetAlertingChannelResponseByName = GetAlertingChannelResponseByName

class ListAlertingChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAlertingChannelRequest = ListAlertingChannelRequest

class ListAlertingChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelDescription]:
        """List of found alerting channels"""
    def __init__(
        self,
        *,
        description: collections.abc.Iterable[qwak.monitoring.v0.alerting_channel_pb2.AlertingChannelDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___ListAlertingChannelResponse = ListAlertingChannelResponse

class DeleteAlertingChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the required alerting channel"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteAlertingChannelRequest = DeleteAlertingChannelRequest

class DeleteAlertingChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteAlertingChannelResponse = DeleteAlertingChannelResponse
