"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.serving.metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetFeaturesetMemoryUsageByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___GetFeaturesetMemoryUsageByIdRequest = GetFeaturesetMemoryUsageByIdRequest

class GetFeaturesetMemoryUsageByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USAGE_FIELD_NUMBER: builtins.int
    @property
    def usage(self) -> qwak.feature_store.serving.metadata_pb2.FeaturesetMemoryUsageStats: ...
    def __init__(
        self,
        *,
        usage: qwak.feature_store.serving.metadata_pb2.FeaturesetMemoryUsageStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["usage", b"usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["usage", b"usage"]) -> None: ...

global___GetFeaturesetMemoryUsageByIdResponse = GetFeaturesetMemoryUsageByIdResponse

class GetFeaturesetMemoryUsageByEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetFeaturesetMemoryUsageByEnvironmentRequest = GetFeaturesetMemoryUsageByEnvironmentRequest

class GetFeaturesetMemoryUsageByEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USAGE_STATS_FIELD_NUMBER: builtins.int
    @property
    def usage_stats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.serving.metadata_pb2.FeaturesetMemoryUsageStats]: ...
    def __init__(
        self,
        *,
        usage_stats: collections.abc.Iterable[qwak.feature_store.serving.metadata_pb2.FeaturesetMemoryUsageStats] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["usage_stats", b"usage_stats"]) -> None: ...

global___GetFeaturesetMemoryUsageByEnvironmentResponse = GetFeaturesetMemoryUsageByEnvironmentResponse
