# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/execution.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from _qwak_proto.qwak.execution.v1 import batch_pb2 as qwak_dot_execution_dot_v1_dot_batch__pb2
from _qwak_proto.qwak.execution.v1 import streaming_pb2 as qwak_dot_execution_dot_v1_dot_streaming__pb2
from _qwak_proto.qwak.execution.v1 import streaming_aggregation_pb2 as qwak_dot_execution_dot_v1_dot_streaming__aggregation__pb2
from _qwak_proto.qwak.execution.v1 import deletion_pb2 as qwak_dot_execution_dot_v1_dot_deletion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/execution/v1/execution.proto\x12\x1fqwak.feature.store.execution.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/execution/v1/backfill.proto\x1a\x1dqwak/execution/v1/batch.proto\x1a!qwak/execution/v1/streaming.proto\x1a-qwak/execution/v1/streaming_aggregation.proto\x1a qwak/execution/v1/deletion.proto\"\x8e\n\n\x0e\x45xecutionEntry\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12J\n\x10\x65xecution_status\x18\x03 \x01(\x0e\x32\x30.qwak.feature.store.execution.v1.ExecutionStatus\x12\x30\n\x0csubmitted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x0csubmitted_by\x18\x05 \x01(\x0b\x32/.qwak.feature.store.execution.v1.InvokerDetails\x12\x30\n\x0ctriggered_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\rbackfill_spec\x18\x08 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpecH\x00\x12J\n\x0f\x62\x61tch_ingestion\x18\t \x01(\x0b\x32/.qwak.feature.store.execution.v1.BatchIngestionH\x00\x12R\n\x13\x66\x65\x61tureset_deletion\x18\n \x01(\x0b\x32\x33.qwak.feature.store.execution.v1.FeaturesetDeletionH\x00\x12_\n\x1aonline_streaming_ingestion\x18\x0b \x01(\x0b\x32\x39.qwak.feature.store.execution.v1.OnlineStreamingIngestionH\x00\x12\x61\n\x1boffline_streaming_ingestion\x18\x0c \x01(\x0b\x32:.qwak.feature.store.execution.v1.OfflineStreamingIngestionH\x00\x12{\n)row_level_streaming_aggregation_ingestion\x18\r \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.RowLevelStreamingAggregationIngestionH\x00\x12~\n*compaction_streaming_aggregation_ingestion\x18\x0e \x01(\x0b\x32H.qwak.feature.store.execution.v1.CompactionStreamingAggregationIngestionH\x00\x12z\n(streaming_aggregation_backfill_ingestion\x18\x0f \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.StreamingAggregationBackfillIngestionH\x00\x12Y\n\x12\x64\x65ployment_details\x18\x10 \x01(\x0b\x32;.qwak.feature.store.execution.v1.ExecutionDeploymentDetailsH\x01\x42\x10\n\x0e\x65xecution_typeB\x18\n\x16\x64\x65ployment_details_opt\"Y\n\x1a\x45xecutionDeploymentDetails\x12\x1c\n\x12\x66\x65\x61tureset_version\x18\x01 \x01(\x05H\x00\x42\x1d\n\x1b\x64\x65ployed_featureset_version\"\xbc\x01\n\x0eInvokerDetails\x12L\n\x10\x65xternal_invoker\x18\x01 \x01(\x0b\x32\x30.qwak.feature.store.execution.v1.ExternalInvokerH\x00\x12L\n\x10internal_invoker\x18\x02 \x01(\x0b\x32\x30.qwak.feature.store.execution.v1.InternalInvokerH\x00\x42\x0e\n\x0cinvoker_type\"(\n\x0f\x45xternalInvoker\x12\x15\n\rinvoker_email\x18\x01 \x01(\t\"\x11\n\x0fInternalInvoker*\xcb\x02\n\x0f\x45xecutionStatus\x12\x1c\n\x18\x45XECUTION_STATUS_INVALID\x10\x00\x12\x1b\n\x17\x45XECUTION_STATUS_QUEUED\x10\x01\x12\x1c\n\x18\x45XECUTION_STATUS_PENDING\x10\x02\x12\x1c\n\x18\x45XECUTION_STATUS_RUNNING\x10\x03\x12\x1e\n\x1a\x45XECUTION_STATUS_COMPLETED\x10\x04\x12\x1b\n\x17\x45XECUTION_STATUS_FAILED\x10\x05\x12\x1e\n\x1a\x45XECUTION_STATUS_CANCELLED\x10\x06\x12\x1e\n\x1a\x45XECUTION_STATUS_SUBMITTED\x10\x07\x12&\n\"EXECUTION_STATUS_FAILED_SUBMISSION\x10\x08\x12\x1c\n\x18\x45XECUTION_STATUS_SKIPPED\x10\tBN\n%com.qwak.ai.features.execution.api.v1P\x01Z#qwak/execution_management;executionb\x06proto3')

_EXECUTIONSTATUS = DESCRIPTOR.enum_types_by_name['ExecutionStatus']
ExecutionStatus = enum_type_wrapper.EnumTypeWrapper(_EXECUTIONSTATUS)
EXECUTION_STATUS_INVALID = 0
EXECUTION_STATUS_QUEUED = 1
EXECUTION_STATUS_PENDING = 2
EXECUTION_STATUS_RUNNING = 3
EXECUTION_STATUS_COMPLETED = 4
EXECUTION_STATUS_FAILED = 5
EXECUTION_STATUS_CANCELLED = 6
EXECUTION_STATUS_SUBMITTED = 7
EXECUTION_STATUS_FAILED_SUBMISSION = 8
EXECUTION_STATUS_SKIPPED = 9


_EXECUTIONENTRY = DESCRIPTOR.message_types_by_name['ExecutionEntry']
_EXECUTIONDEPLOYMENTDETAILS = DESCRIPTOR.message_types_by_name['ExecutionDeploymentDetails']
_INVOKERDETAILS = DESCRIPTOR.message_types_by_name['InvokerDetails']
_EXTERNALINVOKER = DESCRIPTOR.message_types_by_name['ExternalInvoker']
_INTERNALINVOKER = DESCRIPTOR.message_types_by_name['InternalInvoker']
ExecutionEntry = _reflection.GeneratedProtocolMessageType('ExecutionEntry', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONENTRY,
  '__module__' : 'qwak.execution.v1.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ExecutionEntry)
  })
_sym_db.RegisterMessage(ExecutionEntry)

ExecutionDeploymentDetails = _reflection.GeneratedProtocolMessageType('ExecutionDeploymentDetails', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONDEPLOYMENTDETAILS,
  '__module__' : 'qwak.execution.v1.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ExecutionDeploymentDetails)
  })
_sym_db.RegisterMessage(ExecutionDeploymentDetails)

InvokerDetails = _reflection.GeneratedProtocolMessageType('InvokerDetails', (_message.Message,), {
  'DESCRIPTOR' : _INVOKERDETAILS,
  '__module__' : 'qwak.execution.v1.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.InvokerDetails)
  })
_sym_db.RegisterMessage(InvokerDetails)

ExternalInvoker = _reflection.GeneratedProtocolMessageType('ExternalInvoker', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALINVOKER,
  '__module__' : 'qwak.execution.v1.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ExternalInvoker)
  })
_sym_db.RegisterMessage(ExternalInvoker)

InternalInvoker = _reflection.GeneratedProtocolMessageType('InternalInvoker', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALINVOKER,
  '__module__' : 'qwak.execution.v1.execution_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.InternalInvoker)
  })
_sym_db.RegisterMessage(InternalInvoker)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001Z#qwak/execution_management;execution'
  _EXECUTIONSTATUS._serialized_start=1925
  _EXECUTIONSTATUS._serialized_end=2256
  _EXECUTIONENTRY._serialized_start=285
  _EXECUTIONENTRY._serialized_end=1579
  _EXECUTIONDEPLOYMENTDETAILS._serialized_start=1581
  _EXECUTIONDEPLOYMENTDETAILS._serialized_end=1670
  _INVOKERDETAILS._serialized_start=1673
  _INVOKERDETAILS._serialized_end=1861
  _EXTERNALINVOKER._serialized_start=1863
  _EXTERNALINVOKER._serialized_end=1903
  _INTERNALINVOKER._serialized_start=1905
  _INTERNALINVOKER._serialized_end=1922
# @@protoc_insertion_point(module_scope)
